StepAction

Enum StepAction 

pub enum StepAction {
    Prompt {
        prompt: String,
    },
    Skill {
        skill: String,
        arguments: HashMap<String, String>,
    },
}
What a chain step does.

Variants



Prompt

Run an inline prompt. {previous_output} is replaced with the output from the prior step.

Fields

prompt: String

The prompt template.



Skill

Run a registered skill with the given arguments. The special argument _previous_output is automatically set to the output from the prior step.

Fields

skill: String

Skill name.

arguments: HashMap<String, String>

Skill arguments.